@@ -9,7 +9,7 @@ fn main() {
     let secret_number = rand::thread_rng().gen_range(1..=10);
 
     loop {
-        println!("please input your guess or quit with 'quit':");
+        println!("please input your guess:");
 
 
         //println!("The secret number is: {}", secret_number);
